# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from core.metric.v1beta import metric_pb2 as core_dot_metric_dot_v1beta_dot_metric__pb2


class PipelineServiceStub(object):
    """Services related to pipeline trigger records
    Service for get pipeline information 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetPipelines = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelines',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesResponse.FromString,
                )
        self.ReportPipelineTrigger = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/ReportPipelineTrigger',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerResponse.FromString,
                )
        self.ReportPipelineTriggers = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/ReportPipelineTriggers',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersResponse.FromString,
                )
        self.GetPipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsResponse.FromString,
                )
        self.GetBulkPipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsResponse.FromString,
                )
        self.GetCumulativePipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetCumulativePipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsResponse.FromString,
                )
        self.GetBulkCumulativePipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkCumulativePipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsResponse.FromString,
                )
        self.GetPipelineTriggerSummary = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelineTriggerSummary',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryResponse.FromString,
                )
        self.GetBulkPipelineTriggerSummaries = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerSummaries',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesResponse.FromString,
                )
        self.GetPipelineTriggerPrice = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelineTriggerPrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceResponse.FromString,
                )
        self.GetBulkPipelineTriggerPrice = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerPrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceResponse.FromString,
                )


class PipelineServiceServicer(object):
    """Services related to pipeline trigger records
    Service for get pipeline information 
    """

    def GetPipelines(self, request, context):
        """Get pipeline info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportPipelineTrigger(self, request, context):
        """Services for reporting usages 

        For pipeline-backend clients to report a pipeline trigger record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportPipelineTriggers(self, request, context):
        """For pipeline-backend clients to report pipeline trigger records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerRecords(self, request, context):
        """Services for querying usages 

        Get pipeline trigger records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkPipelineTriggerRecords(self, request, context):
        """Get pipeline trigger records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCumulativePipelineTriggerRecords(self, request, context):
        """Get cumulative pipeline trigger records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkCumulativePipelineTriggerRecords(self, request, context):
        """Get cumulative pipeline trigger records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerSummary(self, request, context):
        """Get pipeline trigger summary
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkPipelineTriggerSummaries(self, request, context):
        """Get pipeline trigger summary in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerPrice(self, request, context):
        """Services for querying prices 

        Get pipeline trigger price
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkPipelineTriggerPrice(self, request, context):
        """Get pipeline trigger price in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PipelineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetPipelines': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelines,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesResponse.SerializeToString,
            ),
            'ReportPipelineTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportPipelineTrigger,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerResponse.SerializeToString,
            ),
            'ReportPipelineTriggers': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportPipelineTriggers,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersResponse.SerializeToString,
            ),
            'GetPipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetBulkPipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkPipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetCumulativePipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCumulativePipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetBulkCumulativePipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkCumulativePipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetPipelineTriggerSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerSummary,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryResponse.SerializeToString,
            ),
            'GetBulkPipelineTriggerSummaries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkPipelineTriggerSummaries,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesResponse.SerializeToString,
            ),
            'GetPipelineTriggerPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerPrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceResponse.SerializeToString,
            ),
            'GetBulkPipelineTriggerPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkPipelineTriggerPrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.metric.v1beta.PipelineService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PipelineService(object):
    """Services related to pipeline trigger records
    Service for get pipeline information 
    """

    @staticmethod
    def GetPipelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelines',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportPipelineTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/ReportPipelineTrigger',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportPipelineTriggers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/ReportPipelineTriggers',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkPipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCumulativePipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetCumulativePipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkCumulativePipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkCumulativePipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelineTriggerSummary',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkPipelineTriggerSummaries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerSummaries',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelineTriggerPrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkPipelineTriggerPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerPrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ModelServiceStub(object):
    """Services related to model online records
    Service for get model information 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetModels = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModels',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsResponse.FromString,
                )
        self.ReportModelOnline = channel.unary_unary(
                '/core.metric.v1beta.ModelService/ReportModelOnline',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineResponse.FromString,
                )
        self.ReportModelOnlines = channel.unary_unary(
                '/core.metric.v1beta.ModelService/ReportModelOnlines',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesResponse.FromString,
                )
        self.GetModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsResponse.FromString,
                )
        self.GetBulkModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsResponse.FromString,
                )
        self.GetCumulativeModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetCumulativeModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsResponse.FromString,
                )
        self.GetBulkCumulativeModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkCumulativeModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsResponse.FromString,
                )
        self.GetModelOnlineSummary = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModelOnlineSummary',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryResponse.FromString,
                )
        self.GetBulkModelOnlineSummary = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkModelOnlineSummary',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryResponse.FromString,
                )
        self.GetModelOnlinePrice = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModelOnlinePrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceResponse.FromString,
                )
        self.GetBulkModelOnlinePrice = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkModelOnlinePrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceResponse.FromString,
                )


class ModelServiceServicer(object):
    """Services related to model online records
    Service for get model information 
    """

    def GetModels(self, request, context):
        """Get Model info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportModelOnline(self, request, context):
        """Services for reporting usages 

        For model-backend clients to report a model online record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportModelOnlines(self, request, context):
        """For model-backend clients to report moel online records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOnlineRecords(self, request, context):
        """Services for querying usages 

        Get model online records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkModelOnlineRecords(self, request, context):
        """Get model online records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCumulativeModelOnlineRecords(self, request, context):
        """Get cumulative model online records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkCumulativeModelOnlineRecords(self, request, context):
        """Get cumulative model online records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOnlineSummary(self, request, context):
        """Get model online summary
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkModelOnlineSummary(self, request, context):
        """Get model online summary in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOnlinePrice(self, request, context):
        """Services for querying prices 

        Get model online price
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkModelOnlinePrice(self, request, context):
        """Get model online price in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetModels': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModels,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsResponse.SerializeToString,
            ),
            'ReportModelOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportModelOnline,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineResponse.SerializeToString,
            ),
            'ReportModelOnlines': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportModelOnlines,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesResponse.SerializeToString,
            ),
            'GetModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetBulkModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetCumulativeModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCumulativeModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetBulkCumulativeModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkCumulativeModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetModelOnlineSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOnlineSummary,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryResponse.SerializeToString,
            ),
            'GetBulkModelOnlineSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkModelOnlineSummary,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryResponse.SerializeToString,
            ),
            'GetModelOnlinePrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOnlinePrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceResponse.SerializeToString,
            ),
            'GetBulkModelOnlinePrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkModelOnlinePrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.metric.v1beta.ModelService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelService(object):
    """Services related to model online records
    Service for get model information 
    """

    @staticmethod
    def GetModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModels',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportModelOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/ReportModelOnline',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportModelOnlines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/ReportModelOnlines',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCumulativeModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetCumulativeModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkCumulativeModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkCumulativeModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOnlineSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModelOnlineSummary',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkModelOnlineSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkModelOnlineSummary',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOnlinePrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModelOnlinePrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkModelOnlinePrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkModelOnlinePrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# pylint: disable=no-member,wrong-import-position
from typing import List

# common
from google.protobuf import field_mask_pb2, timestamp_pb2

import instill.protogen.common.healthcheck.v1beta.healthcheck_pb2 as healthcheck

# mgmt
import instill.protogen.core.mgmt.v1beta.metric_pb2 as metric_interface
import instill.protogen.core.mgmt.v1beta.mgmt_pb2 as mgmt_interface
import instill.protogen.core.mgmt.v1beta.mgmt_public_service_pb2_grpc as mgmt_service
from instill.clients.base import Client, RequestFactory
from instill.clients.instance import InstillInstance
from instill.helpers.const import HOST_URL_PROD
from instill.utils.error_handler import grpc_handler


class MgmtClient(Client):
    def __init__(
        self,
        api_token: str,
        url: str = HOST_URL_PROD,
        secure: bool = True,
        requester_id: str = "",
        async_enabled: bool = False,
    ) -> None:

        self.host: InstillInstance = InstillInstance(
            mgmt_service.MgmtPublicServiceStub,
            url=url,
            token=api_token,
            secure=secure,
            async_enabled=async_enabled,
        )

        self.metadata = []

        if requester_id != "":
            requester_uid = self._lookup_namespace_uid(requester_id)
            self.metadata = [("instill-requester-uid", requester_uid)]

    def close(self):
        if self.is_serving():
            self.host.channel.close()

    async def async_close(self):
        if self.is_serving():
            self.host.channel.close()

    @property
    def host(self):
        return self._host

    @host.setter
    def host(self, host: InstillInstance):
        self._host = host

    @property
    def metadata(self):
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: List[tuple]):
        self._metadata = metadata

    def _lookup_namespace_uid(self, namespace_id: str):
        resp = self.check_namespace(namespace_id)
        if resp.type == mgmt_interface.CheckNamespaceAdminResponse.NAMESPACE_USER:
            namespace_uid = self.get_user(namespace_id).user.uid
        elif (
            resp.type
            == mgmt_interface.CheckNamespaceAdminResponse.NAMESPACE_ORGANIZATION
        ):
            namespace_uid = self.get_organization(namespace_id).organization.uid
        else:
            raise Exception("namespace ID not available")

        return namespace_uid

    def liveness(self, async_enabled: bool = False) -> mgmt_interface.LivenessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Liveness,
                request=mgmt_interface.LivenessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Liveness,
            request=mgmt_interface.LivenessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def readiness(
        self, async_enabled: bool = False
    ) -> mgmt_interface.ReadinessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Readiness,
                request=mgmt_interface.ReadinessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Readiness,
            request=mgmt_interface.ReadinessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def is_serving(self) -> bool:
        try:
            return (
                self.readiness().health_check_response.status
                == healthcheck.HealthCheckResponse.SERVING_STATUS_SERVING
            )
        except Exception:
            return False

    @grpc_handler
    def check_namespace(
        self,
        namespace: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.CheckNamespaceResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CheckNamespace,
                request=mgmt_interface.CheckNamespaceRequest(id=namespace),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.CheckNamespace,
            request=mgmt_interface.CheckNamespaceRequest(id=namespace),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_user_membership(
        self,
        user_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.ListUserMembershipsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListUserMemberships,
                request=mgmt_interface.ListUserMembershipsRequest(
                    user_id=user_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListUserMemberships,
            request=mgmt_interface.ListUserMembershipsRequest(
                user_id=user_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_user_membership(
        self,
        user_id: str,
        organization_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetUserMembershipResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetUserMembership,
                request=mgmt_interface.GetUserMembershipRequest(
                    view=mgmt_interface.VIEW_FULL,
                    user_id=user_id,
                    organization_id=organization_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetUserMembership,
            request=mgmt_interface.GetUserMembershipRequest(
                view=mgmt_interface.VIEW_FULL,
                user_id=user_id,
                organization_id=organization_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_user_membership(
        self,
        membership: mgmt_interface.UserMembership,
        mask: field_mask_pb2.FieldMask,
        async_enabled: bool = False,
    ) -> mgmt_interface.UpdateUserMembershipResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateUserMembership,
                request=mgmt_interface.UpdateUserMembershipRequest(
                    membership=membership,
                    update_mask=mask,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()
        return RequestFactory(
            method=self.host.client.UpdateUserMembership,
            request=mgmt_interface.UpdateUserMembershipRequest(
                membership=membership,
                update_mask=mask,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_user_membership(
        self,
        user_id: str,
        organization_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.DeleteUserMembershipResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteUserMembership,
                request=mgmt_interface.DeleteUserMembershipRequest(
                    user_id=user_id,
                    organization_id=organization_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteUserMembership,
            request=mgmt_interface.DeleteUserMembershipRequest(
                user_id=user_id,
                organization_id=organization_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def create_organization(
        self,
        organization: mgmt_interface.Organization,
        async_enabled: bool = False,
    ) -> mgmt_interface.CreateOrganizationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CreateOrganization,
                request=mgmt_interface.CreateOrganizationRequest(
                    organization=organization
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()
        return RequestFactory(
            method=self.host.client.CreateOrganization,
            request=mgmt_interface.CreateOrganizationRequest(organization=organization),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_organization(
        self,
        filter_str: str = "",
        next_page_token: str = "",
        total_size: int = 100,
        async_enabled: bool = False,
    ) -> mgmt_interface.ListOrganizationsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListOrganizations,
                request=mgmt_interface.ListOrganizationsRequest(
                    filter=filter_str,
                    page_size=total_size,
                    page_token=next_page_token,
                    view=mgmt_interface.VIEW_FULL,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()
        return RequestFactory(
            method=self.host.client.ListOrganizations,
            request=mgmt_interface.ListOrganizationsRequest(
                filter=filter_str,
                page_size=total_size,
                page_token=next_page_token,
                view=mgmt_interface.VIEW_FULL,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_organization(
        self,
        organization_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetOrganizationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetOrganization,
                request=mgmt_interface.GetOrganizationRequest(
                    view=mgmt_interface.VIEW_FULL,
                    organization_id=organization_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetOrganization,
            request=mgmt_interface.GetOrganizationRequest(
                view=mgmt_interface.VIEW_FULL,
                organization_id=organization_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_organization(
        self,
        organization: mgmt_interface.Organization,
        mask: field_mask_pb2.FieldMask,
        async_enabled: bool = False,
    ) -> mgmt_interface.UpdateOrganizationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateOrganization,
                request=mgmt_interface.UpdateOrganizationRequest(
                    organization=organization,
                    update_mask=mask,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()
        return RequestFactory(
            method=self.host.client.UpdateOrganization,
            request=mgmt_interface.UpdateOrganizationRequest(
                organization=organization,
                update_mask=mask,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_organization(
        self,
        organization_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.DeleteOrganizationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteOrganization,
                request=mgmt_interface.DeleteOrganizationRequest(
                    organization_id=organization_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteOrganization,
            request=mgmt_interface.DeleteOrganizationRequest(
                organization_id=organization_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_organization_memberships(
        self,
        organization_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.ListOrganizationMembershipsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListOrganizationMemberships,
                request=mgmt_interface.ListOrganizationMembershipsRequest(
                    organization_id=organization_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListOrganizationMemberships,
            request=mgmt_interface.ListOrganizationMembershipsRequest(
                organization_id=organization_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_organization_membership(
        self,
        organization_id: str,
        user_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetOrganizationMembershipResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetOrganizationMembership,
                request=mgmt_interface.GetOrganizationMembershipRequest(
                    view=mgmt_interface.VIEW_FULL,
                    organization_id=organization_id,
                    user_id=user_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetOrganizationMembership,
            request=mgmt_interface.GetOrganizationMembershipRequest(
                view=mgmt_interface.VIEW_FULL,
                organization_id=organization_id,
                user_id=user_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_organization_membership(
        self,
        membership: mgmt_interface.OrganizationMembership,
        mask: field_mask_pb2.FieldMask,
        async_enabled: bool = False,
    ) -> mgmt_interface.UpdateOrganizationMembershipResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateOrganizationMembership,
                request=mgmt_interface.UpdateOrganizationMembershipRequest(
                    membership=membership,
                    update_mask=mask,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()
        return RequestFactory(
            method=self.host.client.UpdateOrganizationMembership,
            request=mgmt_interface.UpdateOrganizationMembershipRequest(
                membership=membership,
                update_mask=mask,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_organization_membership(
        self,
        organization_id: str,
        user_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.DeleteOrganizationMembershipResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteOrganizationMembership,
                request=mgmt_interface.DeleteOrganizationMembershipRequest(
                    organization_id=organization_id,
                    user_id=user_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteOrganizationMembership,
            request=mgmt_interface.DeleteOrganizationMembershipRequest(
                organization_id=organization_id,
                user_id=user_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def login(
        self,
        username="admin",
        password="password",
        async_enabled: bool = False,
    ) -> mgmt_interface.AuthLoginResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.AuthLogin,
                request=mgmt_interface.AuthLoginRequest(
                    username=username, password=password
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.AuthLogin,
            request=mgmt_interface.AuthLoginRequest(
                username=username, password=password
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def create_token(
        self,
        token: mgmt_interface.ApiToken,
        async_enabled: bool = False,
    ) -> mgmt_interface.CreateTokenResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CreateToken,
                request=mgmt_interface.CreateTokenRequest(token=token),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.CreateToken,
            request=mgmt_interface.CreateTokenRequest(token=token),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_token(
        self,
        token_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetTokenResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetToken,
                request=mgmt_interface.GetTokenRequest(
                    token_id=token_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetToken,
            request=mgmt_interface.GetTokenRequest(
                token_id=token_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_tokens(
        self,
        next_page_token: str = "",
        total_size: int = 100,
        async_enabled: bool = False,
    ) -> mgmt_interface.ListTokensResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListTokens,
                request=mgmt_interface.ListTokensRequest(
                    page_size=total_size,
                    page_token=next_page_token,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListTokens,
            request=mgmt_interface.ListTokensRequest(
                page_size=total_size,
                page_token=next_page_token,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_token(
        self,
        token_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.DeleteTokenResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteToken,
                request=mgmt_interface.DeleteTokenRequest(
                    token_id=token_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteToken,
            request=mgmt_interface.DeleteTokenRequest(
                token_id=token_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def validate_token(
        self,
        async_enabled: bool = False,
    ) -> mgmt_interface.ValidateTokenResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ValidateToken,
                request=mgmt_interface.ValidateTokenRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ValidateToken,
            request=mgmt_interface.ValidateTokenRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_user(
        self,
        user_id: str = "me",
        async_enabled: bool = False,
    ) -> mgmt_interface.GetUserResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetUser,
                request=mgmt_interface.GetUserRequest(
                    view=mgmt_interface.VIEW_FULL,
                    user_id=user_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetUser,
            request=mgmt_interface.GetUserRequest(
                view=mgmt_interface.VIEW_FULL,
                user_id=user_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_remaining_credit(
        self,
        namespace_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetRemainingCreditResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetRemainingCredit,
                request=mgmt_interface.GetRemainingCreditRequest(
                    namespace_id=namespace_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetRemainingCredit,
            request=mgmt_interface.GetRemainingCreditRequest(
                namespace_id=namespace_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_pipeline_trigger_table_records(
        self,
        total_size: int = 100,
        next_page_token: str = "",
        filter_str: str = "",
        async_enabled: bool = False,
    ) -> metric_interface.ListPipelineTriggerTableRecordsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListPipelineTriggerTableRecords,
                request=metric_interface.ListPipelineTriggerTableRecordsRequest(
                    page_size=total_size,
                    page_token=next_page_token,
                    filter=filter_str,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListPipelineTriggerTableRecords,
            request=metric_interface.ListPipelineTriggerTableRecordsRequest(
                page_size=total_size,
                page_token=next_page_token,
                filter=filter_str,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_pipeline_trigger_chart_records(
        self,
        aggregation_window: int,
        filter_str: str = "",
        async_enabled: bool = False,
    ) -> metric_interface.ListPipelineTriggerChartRecordsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListPipelineTriggerChartRecords,
                request=metric_interface.ListPipelineTriggerChartRecordsRequest(
                    aggregation_window=aggregation_window,
                    filter=filter_str,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListPipelineTriggerChartRecords,
            request=metric_interface.ListPipelineTriggerChartRecordsRequest(
                aggregation_window=aggregation_window,
                filter=filter_str,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_authenticated_user(
        self,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetAuthenticatedUserResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetAuthenticatedUser,
                request=mgmt_interface.GetAuthenticatedUserRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetAuthenticatedUser,
            request=mgmt_interface.GetAuthenticatedUserRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def patch_authenticated_user(
        self,
        user: mgmt_interface.AuthenticatedUser,
        mask: field_mask_pb2.FieldMask,
        async_enabled: bool = False,
    ) -> mgmt_interface.PatchAuthenticatedUserResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.PatchAuthenticatedUser,
                request=mgmt_interface.PatchAuthenticatedUserRequest(
                    user=user,
                    update_mask=mask,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.PatchAuthenticatedUser,
            request=mgmt_interface.PatchAuthenticatedUserRequest(
                user=user,
                update_mask=mask,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_users(
        self,
        total_size: int = 100,
        next_page_token: str = "",
        filter_str: str = "",
        async_enabled: bool = False,
    ) -> mgmt_interface.ListUsersResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListUsers,
                request=mgmt_interface.ListUsersRequest(
                    page_size=total_size,
                    page_token=next_page_token,
                    view=mgmt_interface.VIEW_FULL,
                    filter=filter_str,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListUsers,
            request=mgmt_interface.ListUsersRequest(
                page_size=total_size,
                page_token=next_page_token,
                view=mgmt_interface.VIEW_FULL,
                filter=filter_str,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_authenticated_subscription(
        self,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetAuthenticatedUserSubscriptionResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetAuthenticatedUserSubscription,
                request=mgmt_interface.GetAuthenticatedUserSubscriptionRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetAuthenticatedUserSubscription,
            request=mgmt_interface.GetAuthenticatedUserSubscriptionRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_organization_subscription(
        self,
        organization_id: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.GetOrganizationSubscriptionResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetOrganizationSubscription,
                request=mgmt_interface.GetOrganizationSubscriptionRequest(
                    organization_id=organization_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetOrganizationSubscription,
            request=mgmt_interface.GetOrganizationSubscriptionRequest(
                organization_id=organization_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_credit_consumption_chart_records(
        self,
        namespace_id: str,
        aggregation_window: str,
        start: timestamp_pb2.Timestamp,
        stop: timestamp_pb2.Timestamp,
        async_enabled: bool = False,
    ) -> metric_interface.ListCreditConsumptionChartRecordsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListCreditConsumptionChartRecords,
                request=metric_interface.ListCreditConsumptionChartRecordsRequest(
                    namespace_id=namespace_id,
                    aggregation_window=aggregation_window,
                    start=start,
                    stop=stop,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListCreditConsumptionChartRecords,
            request=metric_interface.ListCreditConsumptionChartRecordsRequest(
                namespace_id=namespace_id,
                aggregation_window=aggregation_window,
                start=start,
                stop=stop,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def auth_token_issuer(
        self,
        username: str,
        password: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.AuthTokenIssuerResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.AuthTokenIssuer,
                request=mgmt_interface.AuthTokenIssuerRequest(
                    username=username,
                    password=password,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.AuthTokenIssuer,
            request=mgmt_interface.AuthTokenIssuerRequest(
                username=username,
                password=password,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def auth_logout(
        self,
        async_enabled: bool = False,
    ) -> mgmt_interface.AuthLogoutResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.AuthLogout,
                request=mgmt_interface.AuthLogoutRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.AuthLogout,
            request=mgmt_interface.AuthLogoutRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def auth_change_password(
        self,
        old_password: str,
        new_password: str,
        async_enabled: bool = False,
    ) -> mgmt_interface.AuthChangePasswordResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.AuthChangePassword,
                request=mgmt_interface.AuthChangePasswordRequest(
                    old_password=old_password,
                    new_password=new_password,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.AuthChangePassword,
            request=mgmt_interface.AuthChangePasswordRequest(
                old_password=old_password,
                new_password=new_password,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def auth_validate_access_token(
        self,
        async_enabled: bool = False,
    ) -> mgmt_interface.AuthValidateAccessTokenResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.AuthValidateAccessToken,
                request=mgmt_interface.AuthValidateAccessTokenRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.AuthValidateAccessToken,
            request=mgmt_interface.AuthValidateAccessTokenRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2


class ModelPrivateServiceStub(object):
    """Model service responds to internal access
    ========== Private API ==========
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelsAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/ListModelsAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminResponse.FromString,
                )
        self.LookUpModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/LookUpModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminResponse.FromString,
                )
        self.DeployNamespaceModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/DeployNamespaceModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminResponse.FromString,
                )
        self.DeployUserModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/DeployUserModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminResponse.FromString,
                )
        self.DeployOrganizationModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/DeployOrganizationModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminResponse.FromString,
                )
        self.UndeployUserModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/UndeployUserModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminResponse.FromString,
                )
        self.UndeployNamespaceModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/UndeployNamespaceModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminResponse.FromString,
                )
        self.UndeployOrganizationModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/UndeployOrganizationModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminResponse.FromString,
                )


class ModelPrivateServiceServicer(object):
    """Model service responds to internal access
    ========== Private API ==========
    """

    def ListModelsAdmin(self, request, context):
        """ListModelsAdmin method receives a ListModelsAdminRequest message and
        returns a ListModelsAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpModelAdmin(self, request, context):
        """LookUpModelAdmin method receives a LookUpModelAdminRequest message and
        returns a LookUpModelAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployNamespaceModelAdmin(self, request, context):
        """DeployNamespaceModelAdmin deploy a model to online state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployUserModelAdmin(self, request, context):
        """DeployUserModelAdmin deploy a model to online state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployOrganizationModelAdmin(self, request, context):
        """DeployOrganizationModelAdmin deploy a model to online state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployUserModelAdmin(self, request, context):
        """UndeployUserModelAdmin undeploy a model to offline state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployNamespaceModelAdmin(self, request, context):
        """UndeployNamespaceModelAdmin undeploy a model to offline state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployOrganizationModelAdmin(self, request, context):
        """UndeployOrganizationModelAdmin undeploy a model to offline state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPrivateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelsAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelsAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminResponse.SerializeToString,
            ),
            'LookUpModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminResponse.SerializeToString,
            ),
            'DeployNamespaceModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployNamespaceModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminResponse.SerializeToString,
            ),
            'DeployUserModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployUserModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminResponse.SerializeToString,
            ),
            'DeployOrganizationModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployOrganizationModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminResponse.SerializeToString,
            ),
            'UndeployUserModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployUserModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminResponse.SerializeToString,
            ),
            'UndeployNamespaceModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployNamespaceModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminResponse.SerializeToString,
            ),
            'UndeployOrganizationModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployOrganizationModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'model.model.v1alpha.ModelPrivateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPrivateService(object):
    """Model service responds to internal access
    ========== Private API ==========
    """

    @staticmethod
    def ListModelsAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/ListModelsAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/LookUpModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployNamespaceModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/DeployNamespaceModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployUserModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/DeployUserModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployOrganizationModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/DeployOrganizationModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployUserModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/UndeployUserModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployNamespaceModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/UndeployNamespaceModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployOrganizationModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/UndeployOrganizationModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HealthCheckRequest(google.protobuf.message.Message):
    """HealthCheckRequest represents a request to health check a service"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    service: builtins.str
    """Service name to check for its readiness status"""
    def __init__(
        self,
        *,
        service: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_service", b"_service", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_service", b"_service", "service", b"service"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_service", b"_service"]) -> typing_extensions.Literal["service"] | None: ...

global___HealthCheckRequest = HealthCheckRequest

@typing_extensions.final
class HealthCheckResponse(google.protobuf.message.Message):
    """HealthCheckResponse represents a response for a service heath status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServingStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServingStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HealthCheckResponse._ServingStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SERVING_STATUS_UNSPECIFIED: HealthCheckResponse._ServingStatus.ValueType  # 0
        """Serving status: UNSPECIFIED"""
        SERVING_STATUS_SERVING: HealthCheckResponse._ServingStatus.ValueType  # 1
        """Serving status: SERVING"""
        SERVING_STATUS_NOT_SERVING: HealthCheckResponse._ServingStatus.ValueType  # 2
        """Serving status: NOT SERVING"""

    class ServingStatus(_ServingStatus, metaclass=_ServingStatusEnumTypeWrapper):
        """ServingStatus enumerates the status of a queried service"""

    SERVING_STATUS_UNSPECIFIED: HealthCheckResponse.ServingStatus.ValueType  # 0
    """Serving status: UNSPECIFIED"""
    SERVING_STATUS_SERVING: HealthCheckResponse.ServingStatus.ValueType  # 1
    """Serving status: SERVING"""
    SERVING_STATUS_NOT_SERVING: HealthCheckResponse.ServingStatus.ValueType  # 2
    """Serving status: NOT SERVING"""

    STATUS_FIELD_NUMBER: builtins.int
    status: global___HealthCheckResponse.ServingStatus.ValueType
    """Status is the instance of the enum type ServingStatus"""
    def __init__(
        self,
        *,
        status: global___HealthCheckResponse.ServingStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___HealthCheckResponse = HealthCheckResponse



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CallRequest(_message.Message):
    __slots__ = ("task_inputs",)
    TASK_INPUTS_FIELD_NUMBER: _ClassVar[int]
    task_inputs: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    def __init__(self, task_inputs: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...) -> None: ...

class CallResponse(_message.Message):
    __slots__ = ("task_outputs",)
    TASK_OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    task_outputs: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    def __init__(self, task_outputs: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n vdp/pipeline/v1beta/common.proto\x12\x13vdp.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\"\xbb\x03\n\x07Sharing\x12=\n\x05users\x18\x01 \x03(\x0b\x32\'.vdp.pipeline.v1beta.Sharing.UsersEntryR\x05users\x12\x45\n\nshare_code\x18\x02 \x01(\x0b\x32&.vdp.pipeline.v1beta.Sharing.ShareCodeR\tshareCode\x1aO\n\x04User\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12-\n\x04role\x18\x04 \x01(\x0e\x32\x19.vdp.pipeline.v1beta.RoleR\x04role\x1a|\n\tShareCode\x12\x12\n\x04user\x18\x01 \x01(\tR\x04user\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x18\n\x07\x65nabled\x18\x03 \x01(\x08R\x07\x65nabled\x12-\n\x04role\x18\x04 \x01(\x0e\x32\x19.vdp.pipeline.v1beta.RoleR\x04role\x1a[\n\nUsersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32!.vdp.pipeline.v1beta.Sharing.UserR\x05value:\x02\x38\x01\"i\n\nPermission\x12\x19\n\x08\x63\x61n_edit\x18\x01 \x01(\x08R\x07\x63\x61nEdit\x12\x1f\n\x0b\x63\x61n_trigger\x18\x02 \x01(\x08R\ncanTrigger\x12\x1f\n\x0b\x63\x61n_release\x18\x03 \x01(\x08R\ncanRelease\"+\n\x10\x43heckNameRequest\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x04name\"\xac\x01\n\x11\x43heckNameResponse\x12O\n\x0c\x61vailability\x18\x01 \x01(\x0e\x32+.vdp.pipeline.v1beta.CheckNameResponse.NameR\x0c\x61vailability\"F\n\x04Name\x12\x14\n\x10NAME_UNSPECIFIED\x10\x00\x12\x12\n\x0eNAME_AVAILABLE\x10\x01\x12\x14\n\x10NAME_UNAVAILABLE\x10\x02\"j\n\rComponentTask\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x19\n\x05title\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05title\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription*@\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bROLE_VIEWER\x10\x01\x12\x11\n\rROLE_EXECUTOR\x10\x02*\xbe\x01\n\rComponentType\x12\x1e\n\x1a\x43OMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43OMPONENT_TYPE_AI\x10\x01\x12\x17\n\x13\x43OMPONENT_TYPE_DATA\x10\x02\x12\x1b\n\x17\x43OMPONENT_TYPE_OPERATOR\x10\x04\x12\x1e\n\x1a\x43OMPONENT_TYPE_APPLICATION\x10\x05\x12\x1a\n\x16\x43OMPONENT_TYPE_GENERIC\x10\x06\"\x04\x08\x03\x10\x03*;\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\x42\xda\x01\n\x17\x63om.vdp.pipeline.v1betaB\x0b\x43ommonProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\013CommonProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _SHARING_USERSENTRY._options = None
  _SHARING_USERSENTRY._serialized_options = b'8\001'
  _CHECKNAMEREQUEST.fields_by_name['name']._options = None
  _CHECKNAMEREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _COMPONENTTASK.fields_by_name['name']._options = None
  _COMPONENTTASK.fields_by_name['name']._serialized_options = b'\340A\003'
  _COMPONENTTASK.fields_by_name['title']._options = None
  _COMPONENTTASK.fields_by_name['title']._serialized_options = b'\340A\003'
  _COMPONENTTASK.fields_by_name['description']._options = None
  _COMPONENTTASK.fields_by_name['description']._serialized_options = b'\340A\003'
  _globals['_ROLE']._serialized_start=971
  _globals['_ROLE']._serialized_end=1035
  _globals['_COMPONENTTYPE']._serialized_start=1038
  _globals['_COMPONENTTYPE']._serialized_end=1228
  _globals['_VIEW']._serialized_start=1230
  _globals['_VIEW']._serialized_end=1289
  _globals['_SHARING']._serialized_start=91
  _globals['_SHARING']._serialized_end=534
  _globals['_SHARING_USER']._serialized_start=236
  _globals['_SHARING_USER']._serialized_end=315
  _globals['_SHARING_SHARECODE']._serialized_start=317
  _globals['_SHARING_SHARECODE']._serialized_end=441
  _globals['_SHARING_USERSENTRY']._serialized_start=443
  _globals['_SHARING_USERSENTRY']._serialized_end=534
  _globals['_PERMISSION']._serialized_start=536
  _globals['_PERMISSION']._serialized_end=641
  _globals['_CHECKNAMEREQUEST']._serialized_start=643
  _globals['_CHECKNAMEREQUEST']._serialized_end=686
  _globals['_CHECKNAMERESPONSE']._serialized_start=689
  _globals['_CHECKNAMERESPONSE']._serialized_end=861
  _globals['_CHECKNAMERESPONSE_NAME']._serialized_start=791
  _globals['_CHECKNAMERESPONSE_NAME']._serialized_end=861
  _globals['_COMPONENTTASK']._serialized_start=863
  _globals['_COMPONENTTASK']._serialized_end=969
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import common.healthcheck.v1beta.healthcheck_pb2
import common.task.v1alpha.task_pb2
import core.mgmt.v1beta.metric_pb2
import core.mgmt.v1beta.mgmt_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class LivenessRequest(google.protobuf.message.Message):
    """LivenessRequest represents a request to check a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___LivenessRequest = LivenessRequest

@typing_extensions.final
class LivenessResponse(google.protobuf.message.Message):
    """LivenessResponse represents a response for a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___LivenessResponse = LivenessResponse

@typing_extensions.final
class ReadinessRequest(google.protobuf.message.Message):
    """ReadinessRequest represents a request to check a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___ReadinessRequest = ReadinessRequest

@typing_extensions.final
class ReadinessResponse(google.protobuf.message.Message):
    """ReadinessResponse represents a response for a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___ReadinessResponse = ReadinessResponse

@typing_extensions.final
class Session(google.protobuf.message.Message):
    """Session represents a unique session whenever a new instance of VDP service
    gets started. The usage server returns a token that should be used as part of
    the challenge when sending a report with data collected from this session
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Service:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServiceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Session._Service.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SERVICE_UNSPECIFIED: Session._Service.ValueType  # 0
        """Service: UNSPECIFIED"""
        SERVICE_MGMT: Session._Service.ValueType  # 1
        """Service: MGMT"""
        SERVICE_CONNECTOR: Session._Service.ValueType  # 2
        """Service: CONNECTOR"""
        SERVICE_MODEL: Session._Service.ValueType  # 3
        """Service: MODEL"""
        SERVICE_PIPELINE: Session._Service.ValueType  # 4
        """Service: PIPELINE"""
        SERVICE_ARTIFACT: Session._Service.ValueType  # 5
        """Service: ARTIFACT"""

    class Service(_Service, metaclass=_ServiceEnumTypeWrapper):
        """Service enumerates the services to collect data from"""

    SERVICE_UNSPECIFIED: Session.Service.ValueType  # 0
    """Service: UNSPECIFIED"""
    SERVICE_MGMT: Session.Service.ValueType  # 1
    """Service: MGMT"""
    SERVICE_CONNECTOR: Session.Service.ValueType  # 2
    """Service: CONNECTOR"""
    SERVICE_MODEL: Session.Service.ValueType  # 3
    """Service: MODEL"""
    SERVICE_PIPELINE: Session.Service.ValueType  # 4
    """Service: PIPELINE"""
    SERVICE_ARTIFACT: Session.Service.ValueType  # 5
    """Service: ARTIFACT"""

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    EDITION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ARCH_FIELD_NUMBER: builtins.int
    OS_FIELD_NUMBER: builtins.int
    UPTIME_FIELD_NUMBER: builtins.int
    REPORT_TIME_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    OWNER_UID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Resource name in the format of 'sessions/uid'"""
    uid: builtins.str
    """Resource UUID"""
    service: global___Session.Service.ValueType
    """name of the service to collect data from"""
    edition: builtins.str
    """Session edition, allowed values include: 'local-ce' and 'local-ce:dev'"""
    version: builtins.str
    """Version of the service"""
    arch: builtins.str
    """Architecture of the system"""
    os: builtins.str
    """Operating system"""
    uptime: builtins.int
    """Session service uptime"""
    @property
    def report_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Report time"""
    token: builtins.str
    """Token to send report. The token is generated by the server and sent to
    the client. Client needs to use the token to send report to the server.
    """
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Session creation time"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Session update time"""
    owner_uid: builtins.str
    """Owner UUID of the instance, can also be considered as instance UUID"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        service: global___Session.Service.ValueType = ...,
        edition: builtins.str = ...,
        version: builtins.str = ...,
        arch: builtins.str = ...,
        os: builtins.str = ...,
        uptime: builtins.int = ...,
        report_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        token: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        owner_uid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "report_time", b"report_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arch", b"arch", "create_time", b"create_time", "edition", b"edition", "name", b"name", "os", b"os", "owner_uid", b"owner_uid", "report_time", b"report_time", "service", b"service", "token", b"token", "uid", b"uid", "update_time", b"update_time", "uptime", b"uptime", "version", b"version"]) -> None: ...

global___Session = Session

@typing_extensions.final
class MgmtUsageData(google.protobuf.message.Message):
    """Management service usage data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_USAGES_FIELD_NUMBER: builtins.int
    ORG_USAGES_FIELD_NUMBER: builtins.int
    @property
    def user_usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[core.mgmt.v1beta.mgmt_pb2.AuthenticatedUser]:
        """Repeated user usage data"""
    @property
    def org_usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[core.mgmt.v1beta.mgmt_pb2.Organization]:
        """Repeated org usage data"""
    def __init__(
        self,
        *,
        user_usages: collections.abc.Iterable[core.mgmt.v1beta.mgmt_pb2.AuthenticatedUser] | None = ...,
        org_usages: collections.abc.Iterable[core.mgmt.v1beta.mgmt_pb2.Organization] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["org_usages", b"org_usages", "user_usages", b"user_usages"]) -> None: ...

global___MgmtUsageData = MgmtUsageData

@typing_extensions.final
class ConnectorUsageData(google.protobuf.message.Message):
    """Connector service usage data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserUsageData(google.protobuf.message.Message):
        """Per user usage data in the connector service"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing_extensions.final
        class ConnectorExecuteData(google.protobuf.message.Message):
            """Per execute usage metadata"""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            CONNECTOR_UID_FIELD_NUMBER: builtins.int
            EXECUTE_UID_FIELD_NUMBER: builtins.int
            EXECUTE_TIME_FIELD_NUMBER: builtins.int
            CONNECTOR_DEFINITION_UID_FIELD_NUMBER: builtins.int
            STATUS_FIELD_NUMBER: builtins.int
            USER_UID_FIELD_NUMBER: builtins.int
            USER_TYPE_FIELD_NUMBER: builtins.int
            connector_uid: builtins.str
            """UID for the executed connector"""
            execute_uid: builtins.str
            """UID for the execute log"""
            @property
            def execute_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
                """Timestamp for the execution"""
            connector_definition_uid: builtins.str
            """Definition UID of the connector"""
            status: core.mgmt.v1beta.metric_pb2.Status.ValueType
            """Final status of the execution"""
            user_uid: builtins.str
            """UUID of the user who execute the connector"""
            user_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType
            """Type of the user who execute the connector"""
            def __init__(
                self,
                *,
                connector_uid: builtins.str = ...,
                execute_uid: builtins.str = ...,
                execute_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
                connector_definition_uid: builtins.str = ...,
                status: core.mgmt.v1beta.metric_pb2.Status.ValueType = ...,
                user_uid: builtins.str = ...,
                user_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["execute_time", b"execute_time"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["connector_definition_uid", b"connector_definition_uid", "connector_uid", b"connector_uid", "execute_time", b"execute_time", "execute_uid", b"execute_uid", "status", b"status", "user_type", b"user_type", "user_uid", b"user_uid"]) -> None: ...

        OWNER_UID_FIELD_NUMBER: builtins.int
        CONNECTOR_EXECUTE_DATA_FIELD_NUMBER: builtins.int
        OWNER_TYPE_FIELD_NUMBER: builtins.int
        owner_uid: builtins.str
        """Owner UUID"""
        @property
        def connector_execute_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorUsageData.UserUsageData.ConnectorExecuteData]:
            """Execution data for each user"""
        owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType
        """Owner type"""
        def __init__(
            self,
            *,
            owner_uid: builtins.str = ...,
            connector_execute_data: collections.abc.Iterable[global___ConnectorUsageData.UserUsageData.ConnectorExecuteData] | None = ...,
            owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["connector_execute_data", b"connector_execute_data", "owner_type", b"owner_type", "owner_uid", b"owner_uid"]) -> None: ...

    USAGES_FIELD_NUMBER: builtins.int
    @property
    def usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorUsageData.UserUsageData]:
        """Usage data of all users in the connector service"""
    def __init__(
        self,
        *,
        usages: collections.abc.Iterable[global___ConnectorUsageData.UserUsageData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["usages", b"usages"]) -> None: ...

global___ConnectorUsageData = ConnectorUsageData

@typing_extensions.final
class ModelUsageData(google.protobuf.message.Message):
    """Model service usage data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserUsageData(google.protobuf.message.Message):
        """Per user usage data in the model service"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing_extensions.final
        class ModelTriggerData(google.protobuf.message.Message):
            """Per trigger usage metadata"""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            MODEL_UID_FIELD_NUMBER: builtins.int
            TRIGGER_UID_FIELD_NUMBER: builtins.int
            TRIGGER_TIME_FIELD_NUMBER: builtins.int
            MODEL_DEFINITION_UID_FIELD_NUMBER: builtins.int
            MODEL_TASK_FIELD_NUMBER: builtins.int
            STATUS_FIELD_NUMBER: builtins.int
            USER_UID_FIELD_NUMBER: builtins.int
            USER_TYPE_FIELD_NUMBER: builtins.int
            model_uid: builtins.str
            """UID for the trigged model"""
            trigger_uid: builtins.str
            """UID for the trigger log"""
            @property
            def trigger_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
                """Timestamp for the trigger"""
            model_definition_uid: builtins.str
            """Definition UID of the model"""
            model_task: common.task.v1alpha.task_pb2.Task.ValueType
            """Task of the model"""
            status: core.mgmt.v1beta.metric_pb2.Status.ValueType
            """Final status of the execution"""
            user_uid: builtins.str
            """UUID of the user who trigger the model"""
            user_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType
            """Type of the user who trigger the model"""
            def __init__(
                self,
                *,
                model_uid: builtins.str = ...,
                trigger_uid: builtins.str = ...,
                trigger_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
                model_definition_uid: builtins.str = ...,
                model_task: common.task.v1alpha.task_pb2.Task.ValueType = ...,
                status: core.mgmt.v1beta.metric_pb2.Status.ValueType = ...,
                user_uid: builtins.str = ...,
                user_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["trigger_time", b"trigger_time"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["model_definition_uid", b"model_definition_uid", "model_task", b"model_task", "model_uid", b"model_uid", "status", b"status", "trigger_time", b"trigger_time", "trigger_uid", b"trigger_uid", "user_type", b"user_type", "user_uid", b"user_uid"]) -> None: ...

        OWNER_UID_FIELD_NUMBER: builtins.int
        MODEL_TRIGGER_DATA_FIELD_NUMBER: builtins.int
        OWNER_TYPE_FIELD_NUMBER: builtins.int
        owner_uid: builtins.str
        """Owner UUID"""
        @property
        def model_trigger_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelUsageData.UserUsageData.ModelTriggerData]:
            """Trigger data for each user"""
        owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType
        """Owner type"""
        def __init__(
            self,
            *,
            owner_uid: builtins.str = ...,
            model_trigger_data: collections.abc.Iterable[global___ModelUsageData.UserUsageData.ModelTriggerData] | None = ...,
            owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["model_trigger_data", b"model_trigger_data", "owner_type", b"owner_type", "owner_uid", b"owner_uid"]) -> None: ...

    USAGES_FIELD_NUMBER: builtins.int
    @property
    def usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelUsageData.UserUsageData]:
        """Usage data of all users in the model service"""
    def __init__(
        self,
        *,
        usages: collections.abc.Iterable[global___ModelUsageData.UserUsageData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["usages", b"usages"]) -> None: ...

global___ModelUsageData = ModelUsageData

@typing_extensions.final
class PipelineUsageData(google.protobuf.message.Message):
    """Pipeline service usage data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserUsageData(google.protobuf.message.Message):
        """Per user usage data in the pipeline service"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing_extensions.final
        class PipelineTriggerData(google.protobuf.message.Message):
            """Per trigger usage metadata"""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            PIPELINE_UID_FIELD_NUMBER: builtins.int
            TRIGGER_UID_FIELD_NUMBER: builtins.int
            TRIGGER_TIME_FIELD_NUMBER: builtins.int
            TRIGGER_MODE_FIELD_NUMBER: builtins.int
            STATUS_FIELD_NUMBER: builtins.int
            PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
            PIPELINE_RELEASE_UID_FIELD_NUMBER: builtins.int
            USER_UID_FIELD_NUMBER: builtins.int
            USER_TYPE_FIELD_NUMBER: builtins.int
            PIPELINE_ID_FIELD_NUMBER: builtins.int
            pipeline_uid: builtins.str
            """UID for the triggered pipeline"""
            trigger_uid: builtins.str
            """UID for the trigger log"""
            @property
            def trigger_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
                """Timestamp for the trigger"""
            trigger_mode: core.mgmt.v1beta.metric_pb2.Mode.ValueType
            """Trigger mode"""
            status: core.mgmt.v1beta.metric_pb2.Status.ValueType
            """Final status of the execution"""
            pipeline_release_id: builtins.str
            """Version for the triggered release pipeline, empty string if not release"""
            pipeline_release_uid: builtins.str
            """UID for the triggered release pipeline, empty string if not release"""
            user_uid: builtins.str
            """UUID of the user who trigger the pipeline"""
            user_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType
            """Type of the user who trigger the pipeline"""
            pipeline_id: builtins.str
            """ID for the triggered pipeline"""
            def __init__(
                self,
                *,
                pipeline_uid: builtins.str = ...,
                trigger_uid: builtins.str = ...,
                trigger_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
                trigger_mode: core.mgmt.v1beta.metric_pb2.Mode.ValueType = ...,
                status: core.mgmt.v1beta.metric_pb2.Status.ValueType = ...,
                pipeline_release_id: builtins.str = ...,
                pipeline_release_uid: builtins.str = ...,
                user_uid: builtins.str = ...,
                user_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType = ...,
                pipeline_id: builtins.str = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["trigger_time", b"trigger_time"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["pipeline_id", b"pipeline_id", "pipeline_release_id", b"pipeline_release_id", "pipeline_release_uid", b"pipeline_release_uid", "pipeline_uid", b"pipeline_uid", "status", b"status", "trigger_mode", b"trigger_mode", "trigger_time", b"trigger_time", "trigger_uid", b"trigger_uid", "user_type", b"user_type", "user_uid", b"user_uid"]) -> None: ...

        OWNER_UID_FIELD_NUMBER: builtins.int
        PIPELINE_TRIGGER_DATA_FIELD_NUMBER: builtins.int
        OWNER_TYPE_FIELD_NUMBER: builtins.int
        owner_uid: builtins.str
        """Owner UUID"""
        @property
        def pipeline_trigger_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineUsageData.UserUsageData.PipelineTriggerData]:
            """Trigger data for each user"""
        owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType
        """Owner type"""
        def __init__(
            self,
            *,
            owner_uid: builtins.str = ...,
            pipeline_trigger_data: collections.abc.Iterable[global___PipelineUsageData.UserUsageData.PipelineTriggerData] | None = ...,
            owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["owner_type", b"owner_type", "owner_uid", b"owner_uid", "pipeline_trigger_data", b"pipeline_trigger_data"]) -> None: ...

    USAGES_FIELD_NUMBER: builtins.int
    @property
    def usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineUsageData.UserUsageData]:
        """Usage data of all users in the pipeline service"""
    def __init__(
        self,
        *,
        usages: collections.abc.Iterable[global___PipelineUsageData.UserUsageData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["usages", b"usages"]) -> None: ...

global___PipelineUsageData = PipelineUsageData

@typing_extensions.final
class ArtifactUsageData(google.protobuf.message.Message):
    """Artifact service usage data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserUsageData(google.protobuf.message.Message):
        """Per user usage data in the artifact service"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        OWNER_UID_FIELD_NUMBER: builtins.int
        OWNER_TYPE_FIELD_NUMBER: builtins.int
        owner_uid: builtins.str
        """Owner UUID"""
        owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType
        """Owner type"""
        def __init__(
            self,
            *,
            owner_uid: builtins.str = ...,
            owner_type: core.mgmt.v1beta.mgmt_pb2.OwnerType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["owner_type", b"owner_type", "owner_uid", b"owner_uid"]) -> None: ...

    USAGES_FIELD_NUMBER: builtins.int
    @property
    def usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ArtifactUsageData.UserUsageData]:
        """Usage data of all users in the artifact service"""
    def __init__(
        self,
        *,
        usages: collections.abc.Iterable[global___ArtifactUsageData.UserUsageData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["usages", b"usages"]) -> None: ...

global___ArtifactUsageData = ArtifactUsageData

@typing_extensions.final
class SessionReport(google.protobuf.message.Message):
    """SessionReport represents a report to be sent to the server that includes the
    usage data of a session
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_UID_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    POW_FIELD_NUMBER: builtins.int
    SESSION_FIELD_NUMBER: builtins.int
    MGMT_USAGE_DATA_FIELD_NUMBER: builtins.int
    CONNECTOR_USAGE_DATA_FIELD_NUMBER: builtins.int
    MODEL_USAGE_DATA_FIELD_NUMBER: builtins.int
    PIPELINE_USAGE_DATA_FIELD_NUMBER: builtins.int
    ARTIFACT_USAGE_DATA_FIELD_NUMBER: builtins.int
    session_uid: builtins.str
    """Session uid"""
    token: builtins.str
    """Session token"""
    pow: builtins.str
    """Proof-of-work See https://en.wikipedia.org/wiki/Proof_of_work"""
    @property
    def session(self) -> global___Session:
        """Session"""
    @property
    def mgmt_usage_data(self) -> global___MgmtUsageData:
        """Management service usage data"""
    @property
    def connector_usage_data(self) -> global___ConnectorUsageData:
        """Connector service usage data"""
    @property
    def model_usage_data(self) -> global___ModelUsageData:
        """Model service usage data"""
    @property
    def pipeline_usage_data(self) -> global___PipelineUsageData:
        """Pipeline service usage data"""
    @property
    def artifact_usage_data(self) -> global___ArtifactUsageData:
        """Artifact service usage data"""
    def __init__(
        self,
        *,
        session_uid: builtins.str = ...,
        token: builtins.str = ...,
        pow: builtins.str = ...,
        session: global___Session | None = ...,
        mgmt_usage_data: global___MgmtUsageData | None = ...,
        connector_usage_data: global___ConnectorUsageData | None = ...,
        model_usage_data: global___ModelUsageData | None = ...,
        pipeline_usage_data: global___PipelineUsageData | None = ...,
        artifact_usage_data: global___ArtifactUsageData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifact_usage_data", b"artifact_usage_data", "connector_usage_data", b"connector_usage_data", "mgmt_usage_data", b"mgmt_usage_data", "model_usage_data", b"model_usage_data", "pipeline_usage_data", b"pipeline_usage_data", "session", b"session", "usage_data", b"usage_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_usage_data", b"artifact_usage_data", "connector_usage_data", b"connector_usage_data", "mgmt_usage_data", b"mgmt_usage_data", "model_usage_data", b"model_usage_data", "pipeline_usage_data", b"pipeline_usage_data", "pow", b"pow", "session", b"session", "session_uid", b"session_uid", "token", b"token", "usage_data", b"usage_data"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["usage_data", b"usage_data"]) -> typing_extensions.Literal["mgmt_usage_data", "connector_usage_data", "model_usage_data", "pipeline_usage_data", "artifact_usage_data"] | None: ...

global___SessionReport = SessionReport

@typing_extensions.final
class CreateSessionRequest(google.protobuf.message.Message):
    """CreateSessionRequest represents a request to create a new session"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    @property
    def session(self) -> global___Session:
        """A session resource to create"""
    def __init__(
        self,
        *,
        session: global___Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["session", b"session"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session"]) -> None: ...

global___CreateSessionRequest = CreateSessionRequest

@typing_extensions.final
class CreateSessionResponse(google.protobuf.message.Message):
    """CreateSessionResponse represents a response for a session response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    @property
    def session(self) -> global___Session:
        """A session resource"""
    def __init__(
        self,
        *,
        session: global___Session | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["session", b"session"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["session", b"session"]) -> None: ...

global___CreateSessionResponse = CreateSessionResponse

@typing_extensions.final
class SendSessionReportRequest(google.protobuf.message.Message):
    """SendReportRequest represents a request to send a usage report"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPORT_FIELD_NUMBER: builtins.int
    @property
    def report(self) -> global___SessionReport:
        """A report resource to create"""
    def __init__(
        self,
        *,
        report: global___SessionReport | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["report", b"report"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["report", b"report"]) -> None: ...

global___SendSessionReportRequest = SendSessionReportRequest

@typing_extensions.final
class SendSessionReportResponse(google.protobuf.message.Message):
    """SendReportResponse represents an empty response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SendSessionReportResponse = SendSessionReportResponse
